# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectBranchesResult',
    'AwaitableGetProjectBranchesResult',
    'get_project_branches',
    'get_project_branches_output',
]

@pulumi.output_type
class GetProjectBranchesResult:
    """
    A collection of values returned by getProjectBranches.
    """
    def __init__(__self__, branches=None, id=None, project=None):
        if branches and not isinstance(branches, list):
            raise TypeError("Expected argument 'branches' to be a list")
        pulumi.set(__self__, "branches", branches)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)

    @_builtins.property
    @pulumi.getter
    def branches(self) -> Sequence['outputs.GetProjectBranchesBranchResult']:
        """
        The list of branches of the project, as defined below.
        """
        return pulumi.get(self, "branches")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        ID or URL-encoded path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")


class AwaitableGetProjectBranchesResult(GetProjectBranchesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectBranchesResult(
            branches=self.branches,
            id=self.id,
            project=self.project)


def get_project_branches(project: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectBranchesResult:
    """
    The `get_project_branches` data source allows details of the branches of a given project to be retrieved.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/branches/#list-repository-branches)


    :param _builtins.str project: ID or URL-encoded path of the project owned by the authenticated user.
    """
    __args__ = dict()
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectBranches:getProjectBranches', __args__, opts=opts, typ=GetProjectBranchesResult).value

    return AwaitableGetProjectBranchesResult(
        branches=pulumi.get(__ret__, 'branches'),
        id=pulumi.get(__ret__, 'id'),
        project=pulumi.get(__ret__, 'project'))
def get_project_branches_output(project: Optional[pulumi.Input[_builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectBranchesResult]:
    """
    The `get_project_branches` data source allows details of the branches of a given project to be retrieved.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/branches/#list-repository-branches)


    :param _builtins.str project: ID or URL-encoded path of the project owned by the authenticated user.
    """
    __args__ = dict()
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectBranches:getProjectBranches', __args__, opts=opts, typ=GetProjectBranchesResult)
    return __ret__.apply(lambda __response__: GetProjectBranchesResult(
        branches=pulumi.get(__response__, 'branches'),
        id=pulumi.get(__response__, 'id'),
        project=pulumi.get(__response__, 'project')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetProjectIdsResult',
    'AwaitableGetProjectIdsResult',
    'get_project_ids',
    'get_project_ids_output',
]

@pulumi.output_type
class GetProjectIdsResult:
    """
    A collection of values returned by getProjectIds.
    """
    def __init__(__self__, id=None, project=None, project_full_path=None, project_graphql_id=None, project_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if project_full_path and not isinstance(project_full_path, str):
            raise TypeError("Expected argument 'project_full_path' to be a str")
        pulumi.set(__self__, "project_full_path", project_full_path)
        if project_graphql_id and not isinstance(project_graphql_id, str):
            raise TypeError("Expected argument 'project_graphql_id' to be a str")
        pulumi.set(__self__, "project_graphql_id", project_graphql_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="projectFullPath")
    def project_full_path(self) -> _builtins.str:
        """
        The full path of the project.
        """
        return pulumi.get(self, "project_full_path")

    @_builtins.property
    @pulumi.getter(name="projectGraphqlId")
    def project_graphql_id(self) -> _builtins.str:
        """
        The GraphQL ID of the project.
        """
        return pulumi.get(self, "project_graphql_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")


class AwaitableGetProjectIdsResult(GetProjectIdsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectIdsResult(
            id=self.id,
            project=self.project,
            project_full_path=self.project_full_path,
            project_graphql_id=self.project_graphql_id,
            project_id=self.project_id)


def get_project_ids(project: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectIdsResult:
    """
    The `get_project_ids` data source identification information for a given project, allowing a user to translate a full path or ID into the GraphQL ID of the project.

    **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#queryproject)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    new_project = gitlab.Project("new_project", name="project")
    # use project IDs to get additional information, such as the GraphQL ID
    # for other resources
    foo = gitlab.get_project_ids(project="gitlab_project.new_project.id")
    pulumi.export("graphQLId", foo.project_graphql_id)
    ```


    :param _builtins.str project: The ID or URL-encoded path of the project.
    """
    __args__ = dict()
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectIds:getProjectIds', __args__, opts=opts, typ=GetProjectIdsResult).value

    return AwaitableGetProjectIdsResult(
        id=pulumi.get(__ret__, 'id'),
        project=pulumi.get(__ret__, 'project'),
        project_full_path=pulumi.get(__ret__, 'project_full_path'),
        project_graphql_id=pulumi.get(__ret__, 'project_graphql_id'),
        project_id=pulumi.get(__ret__, 'project_id'))
def get_project_ids_output(project: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectIdsResult]:
    """
    The `get_project_ids` data source identification information for a given project, allowing a user to translate a full path or ID into the GraphQL ID of the project.

    **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#queryproject)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    new_project = gitlab.Project("new_project", name="project")
    # use project IDs to get additional information, such as the GraphQL ID
    # for other resources
    foo = gitlab.get_project_ids(project="gitlab_project.new_project.id")
    pulumi.export("graphQLId", foo.project_graphql_id)
    ```


    :param _builtins.str project: The ID or URL-encoded path of the project.
    """
    __args__ = dict()
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectIds:getProjectIds', __args__, opts=opts, typ=GetProjectIdsResult)
    return __ret__.apply(lambda __response__: GetProjectIdsResult(
        id=pulumi.get(__response__, 'id'),
        project=pulumi.get(__response__, 'project'),
        project_full_path=pulumi.get(__response__, 'project_full_path'),
        project_graphql_id=pulumi.get(__response__, 'project_graphql_id'),
        project_id=pulumi.get(__response__, 'project_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectProtectedTagResult',
    'AwaitableGetProjectProtectedTagResult',
    'get_project_protected_tag',
    'get_project_protected_tag_output',
]

@pulumi.output_type
class GetProjectProtectedTagResult:
    """
    A collection of values returned by getProjectProtectedTag.
    """
    def __init__(__self__, create_access_levels=None, id=None, project=None, tag=None):
        if create_access_levels and not isinstance(create_access_levels, list):
            raise TypeError("Expected argument 'create_access_levels' to be a list")
        pulumi.set(__self__, "create_access_levels", create_access_levels)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if tag and not isinstance(tag, str):
            raise TypeError("Expected argument 'tag' to be a str")
        pulumi.set(__self__, "tag", tag)

    @_builtins.property
    @pulumi.getter(name="createAccessLevels")
    def create_access_levels(self) -> Sequence['outputs.GetProjectProtectedTagCreateAccessLevelResult']:
        """
        Array of access levels/user(s)/group(s) allowed to create protected tags.
        """
        return pulumi.get(self, "create_access_levels")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this resource. In the format of `<tag>`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The integer or path with namespace that uniquely identifies the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def tag(self) -> _builtins.str:
        """
        The name of the protected tag.
        """
        return pulumi.get(self, "tag")


class AwaitableGetProjectProtectedTagResult(GetProjectProtectedTagResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectProtectedTagResult(
            create_access_levels=self.create_access_levels,
            id=self.id,
            project=self.project,
            tag=self.tag)


def get_project_protected_tag(project: Optional[_builtins.str] = None,
                              tag: Optional[_builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectProtectedTagResult:
    """
    The `get_project_protected_tag` data source allows details of a protected tag to be retrieved by its name and the project it belongs to.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/protected_tags/#get-a-single-protected-tag-or-wildcard-protected-tag)


    :param _builtins.str project: The integer or path with namespace that uniquely identifies the project.
    :param _builtins.str tag: The name of the protected tag.
    """
    __args__ = dict()
    __args__['project'] = project
    __args__['tag'] = tag
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectProtectedTag:getProjectProtectedTag', __args__, opts=opts, typ=GetProjectProtectedTagResult).value

    return AwaitableGetProjectProtectedTagResult(
        create_access_levels=pulumi.get(__ret__, 'create_access_levels'),
        id=pulumi.get(__ret__, 'id'),
        project=pulumi.get(__ret__, 'project'),
        tag=pulumi.get(__ret__, 'tag'))
def get_project_protected_tag_output(project: Optional[pulumi.Input[_builtins.str]] = None,
                                     tag: Optional[pulumi.Input[_builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectProtectedTagResult]:
    """
    The `get_project_protected_tag` data source allows details of a protected tag to be retrieved by its name and the project it belongs to.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/protected_tags/#get-a-single-protected-tag-or-wildcard-protected-tag)


    :param _builtins.str project: The integer or path with namespace that uniquely identifies the project.
    :param _builtins.str tag: The name of the protected tag.
    """
    __args__ = dict()
    __args__['project'] = project
    __args__['tag'] = tag
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectProtectedTag:getProjectProtectedTag', __args__, opts=opts, typ=GetProjectProtectedTagResult)
    return __ret__.apply(lambda __response__: GetProjectProtectedTagResult(
        create_access_levels=pulumi.get(__response__, 'create_access_levels'),
        id=pulumi.get(__response__, 'id'),
        project=pulumi.get(__response__, 'project'),
        tag=pulumi.get(__response__, 'tag')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ApplicationAppearanceArgs', 'ApplicationAppearance']

@pulumi.input_type
class ApplicationAppearanceArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email_header_and_footer_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 footer_message: Optional[pulumi.Input[_builtins.str]] = None,
                 header_message: Optional[pulumi.Input[_builtins.str]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 member_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 message_background_color: Optional[pulumi.Input[_builtins.str]] = None,
                 message_font_color: Optional[pulumi.Input[_builtins.str]] = None,
                 new_project_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 profile_image_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_description: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_name: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_short_name: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ApplicationAppearance resource.
        :param pulumi.Input[_builtins.str] description: Markdown text shown on the sign-in and sign-up page.
        :param pulumi.Input[_builtins.bool] email_header_and_footer_enabled: Add header and footer to all outgoing emails if enabled.
        :param pulumi.Input[_builtins.str] footer_message: Message in the system footer bar.
        :param pulumi.Input[_builtins.str] header_message: Message in the system header bar.
        :param pulumi.Input[_builtins.str] member_guidelines: Markdown text shown on the group or project member page for users with permission to change members.
        :param pulumi.Input[_builtins.str] message_background_color: Background color for the system header or footer bar, in CSS hex notation.
        :param pulumi.Input[_builtins.str] message_font_color: Font color for the system header or footer bar, in CSS hex notation.
        :param pulumi.Input[_builtins.str] new_project_guidelines: Markdown text shown on the new project page.
        :param pulumi.Input[_builtins.str] profile_image_guidelines: Markdown text shown on the profile page below the Public Avatar.
        :param pulumi.Input[_builtins.str] pwa_description: An explanation of what the Progressive Web App does. Used for the attribute `description` in `manifest.json`.
        :param pulumi.Input[_builtins.str] pwa_name: Full name of the Progressive Web App. Used for the attribute `name` in `manifest.json`.
        :param pulumi.Input[_builtins.str] pwa_short_name: Short name for Progressive Web App.
        :param pulumi.Input[_builtins.str] title: Application title on the sign-in and sign-up page.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email_header_and_footer_enabled is not None:
            pulumi.set(__self__, "email_header_and_footer_enabled", email_header_and_footer_enabled)
        if footer_message is not None:
            pulumi.set(__self__, "footer_message", footer_message)
        if header_message is not None:
            pulumi.set(__self__, "header_message", header_message)
        if keep_settings_on_destroy is not None:
            pulumi.set(__self__, "keep_settings_on_destroy", keep_settings_on_destroy)
        if member_guidelines is not None:
            pulumi.set(__self__, "member_guidelines", member_guidelines)
        if message_background_color is not None:
            pulumi.set(__self__, "message_background_color", message_background_color)
        if message_font_color is not None:
            pulumi.set(__self__, "message_font_color", message_font_color)
        if new_project_guidelines is not None:
            pulumi.set(__self__, "new_project_guidelines", new_project_guidelines)
        if profile_image_guidelines is not None:
            pulumi.set(__self__, "profile_image_guidelines", profile_image_guidelines)
        if pwa_description is not None:
            pulumi.set(__self__, "pwa_description", pwa_description)
        if pwa_name is not None:
            pulumi.set(__self__, "pwa_name", pwa_name)
        if pwa_short_name is not None:
            pulumi.set(__self__, "pwa_short_name", pwa_short_name)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Markdown text shown on the sign-in and sign-up page.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="emailHeaderAndFooterEnabled")
    def email_header_and_footer_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Add header and footer to all outgoing emails if enabled.
        """
        return pulumi.get(self, "email_header_and_footer_enabled")

    @email_header_and_footer_enabled.setter
    def email_header_and_footer_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "email_header_and_footer_enabled", value)

    @_builtins.property
    @pulumi.getter(name="footerMessage")
    def footer_message(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Message in the system footer bar.
        """
        return pulumi.get(self, "footer_message")

    @footer_message.setter
    def footer_message(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "footer_message", value)

    @_builtins.property
    @pulumi.getter(name="headerMessage")
    def header_message(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Message in the system header bar.
        """
        return pulumi.get(self, "header_message")

    @header_message.setter
    def header_message(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "header_message", value)

    @_builtins.property
    @pulumi.getter(name="keepSettingsOnDestroy")
    def keep_settings_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "keep_settings_on_destroy")

    @keep_settings_on_destroy.setter
    def keep_settings_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_settings_on_destroy", value)

    @_builtins.property
    @pulumi.getter(name="memberGuidelines")
    def member_guidelines(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Markdown text shown on the group or project member page for users with permission to change members.
        """
        return pulumi.get(self, "member_guidelines")

    @member_guidelines.setter
    def member_guidelines(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "member_guidelines", value)

    @_builtins.property
    @pulumi.getter(name="messageBackgroundColor")
    def message_background_color(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Background color for the system header or footer bar, in CSS hex notation.
        """
        return pulumi.get(self, "message_background_color")

    @message_background_color.setter
    def message_background_color(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "message_background_color", value)

    @_builtins.property
    @pulumi.getter(name="messageFontColor")
    def message_font_color(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Font color for the system header or footer bar, in CSS hex notation.
        """
        return pulumi.get(self, "message_font_color")

    @message_font_color.setter
    def message_font_color(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "message_font_color", value)

    @_builtins.property
    @pulumi.getter(name="newProjectGuidelines")
    def new_project_guidelines(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Markdown text shown on the new project page.
        """
        return pulumi.get(self, "new_project_guidelines")

    @new_project_guidelines.setter
    def new_project_guidelines(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "new_project_guidelines", value)

    @_builtins.property
    @pulumi.getter(name="profileImageGuidelines")
    def profile_image_guidelines(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Markdown text shown on the profile page below the Public Avatar.
        """
        return pulumi.get(self, "profile_image_guidelines")

    @profile_image_guidelines.setter
    def profile_image_guidelines(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile_image_guidelines", value)

    @_builtins.property
    @pulumi.getter(name="pwaDescription")
    def pwa_description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        An explanation of what the Progressive Web App does. Used for the attribute `description` in `manifest.json`.
        """
        return pulumi.get(self, "pwa_description")

    @pwa_description.setter
    def pwa_description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pwa_description", value)

    @_builtins.property
    @pulumi.getter(name="pwaName")
    def pwa_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Full name of the Progressive Web App. Used for the attribute `name` in `manifest.json`.
        """
        return pulumi.get(self, "pwa_name")

    @pwa_name.setter
    def pwa_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pwa_name", value)

    @_builtins.property
    @pulumi.getter(name="pwaShortName")
    def pwa_short_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Short name for Progressive Web App.
        """
        return pulumi.get(self, "pwa_short_name")

    @pwa_short_name.setter
    def pwa_short_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pwa_short_name", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application title on the sign-in and sign-up page.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "title", value)


@pulumi.input_type
class _ApplicationAppearanceState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email_header_and_footer_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 footer_message: Optional[pulumi.Input[_builtins.str]] = None,
                 header_message: Optional[pulumi.Input[_builtins.str]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 member_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 message_background_color: Optional[pulumi.Input[_builtins.str]] = None,
                 message_font_color: Optional[pulumi.Input[_builtins.str]] = None,
                 new_project_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 profile_image_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_description: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_name: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_short_name: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ApplicationAppearance resources.
        :param pulumi.Input[_builtins.str] description: Markdown text shown on the sign-in and sign-up page.
        :param pulumi.Input[_builtins.bool] email_header_and_footer_enabled: Add header and footer to all outgoing emails if enabled.
        :param pulumi.Input[_builtins.str] footer_message: Message in the system footer bar.
        :param pulumi.Input[_builtins.str] header_message: Message in the system header bar.
        :param pulumi.Input[_builtins.str] member_guidelines: Markdown text shown on the group or project member page for users with permission to change members.
        :param pulumi.Input[_builtins.str] message_background_color: Background color for the system header or footer bar, in CSS hex notation.
        :param pulumi.Input[_builtins.str] message_font_color: Font color for the system header or footer bar, in CSS hex notation.
        :param pulumi.Input[_builtins.str] new_project_guidelines: Markdown text shown on the new project page.
        :param pulumi.Input[_builtins.str] profile_image_guidelines: Markdown text shown on the profile page below the Public Avatar.
        :param pulumi.Input[_builtins.str] pwa_description: An explanation of what the Progressive Web App does. Used for the attribute `description` in `manifest.json`.
        :param pulumi.Input[_builtins.str] pwa_name: Full name of the Progressive Web App. Used for the attribute `name` in `manifest.json`.
        :param pulumi.Input[_builtins.str] pwa_short_name: Short name for Progressive Web App.
        :param pulumi.Input[_builtins.str] title: Application title on the sign-in and sign-up page.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email_header_and_footer_enabled is not None:
            pulumi.set(__self__, "email_header_and_footer_enabled", email_header_and_footer_enabled)
        if footer_message is not None:
            pulumi.set(__self__, "footer_message", footer_message)
        if header_message is not None:
            pulumi.set(__self__, "header_message", header_message)
        if keep_settings_on_destroy is not None:
            pulumi.set(__self__, "keep_settings_on_destroy", keep_settings_on_destroy)
        if member_guidelines is not None:
            pulumi.set(__self__, "member_guidelines", member_guidelines)
        if message_background_color is not None:
            pulumi.set(__self__, "message_background_color", message_background_color)
        if message_font_color is not None:
            pulumi.set(__self__, "message_font_color", message_font_color)
        if new_project_guidelines is not None:
            pulumi.set(__self__, "new_project_guidelines", new_project_guidelines)
        if profile_image_guidelines is not None:
            pulumi.set(__self__, "profile_image_guidelines", profile_image_guidelines)
        if pwa_description is not None:
            pulumi.set(__self__, "pwa_description", pwa_description)
        if pwa_name is not None:
            pulumi.set(__self__, "pwa_name", pwa_name)
        if pwa_short_name is not None:
            pulumi.set(__self__, "pwa_short_name", pwa_short_name)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Markdown text shown on the sign-in and sign-up page.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="emailHeaderAndFooterEnabled")
    def email_header_and_footer_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Add header and footer to all outgoing emails if enabled.
        """
        return pulumi.get(self, "email_header_and_footer_enabled")

    @email_header_and_footer_enabled.setter
    def email_header_and_footer_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "email_header_and_footer_enabled", value)

    @_builtins.property
    @pulumi.getter(name="footerMessage")
    def footer_message(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Message in the system footer bar.
        """
        return pulumi.get(self, "footer_message")

    @footer_message.setter
    def footer_message(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "footer_message", value)

    @_builtins.property
    @pulumi.getter(name="headerMessage")
    def header_message(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Message in the system header bar.
        """
        return pulumi.get(self, "header_message")

    @header_message.setter
    def header_message(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "header_message", value)

    @_builtins.property
    @pulumi.getter(name="keepSettingsOnDestroy")
    def keep_settings_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "keep_settings_on_destroy")

    @keep_settings_on_destroy.setter
    def keep_settings_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_settings_on_destroy", value)

    @_builtins.property
    @pulumi.getter(name="memberGuidelines")
    def member_guidelines(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Markdown text shown on the group or project member page for users with permission to change members.
        """
        return pulumi.get(self, "member_guidelines")

    @member_guidelines.setter
    def member_guidelines(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "member_guidelines", value)

    @_builtins.property
    @pulumi.getter(name="messageBackgroundColor")
    def message_background_color(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Background color for the system header or footer bar, in CSS hex notation.
        """
        return pulumi.get(self, "message_background_color")

    @message_background_color.setter
    def message_background_color(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "message_background_color", value)

    @_builtins.property
    @pulumi.getter(name="messageFontColor")
    def message_font_color(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Font color for the system header or footer bar, in CSS hex notation.
        """
        return pulumi.get(self, "message_font_color")

    @message_font_color.setter
    def message_font_color(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "message_font_color", value)

    @_builtins.property
    @pulumi.getter(name="newProjectGuidelines")
    def new_project_guidelines(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Markdown text shown on the new project page.
        """
        return pulumi.get(self, "new_project_guidelines")

    @new_project_guidelines.setter
    def new_project_guidelines(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "new_project_guidelines", value)

    @_builtins.property
    @pulumi.getter(name="profileImageGuidelines")
    def profile_image_guidelines(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Markdown text shown on the profile page below the Public Avatar.
        """
        return pulumi.get(self, "profile_image_guidelines")

    @profile_image_guidelines.setter
    def profile_image_guidelines(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile_image_guidelines", value)

    @_builtins.property
    @pulumi.getter(name="pwaDescription")
    def pwa_description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        An explanation of what the Progressive Web App does. Used for the attribute `description` in `manifest.json`.
        """
        return pulumi.get(self, "pwa_description")

    @pwa_description.setter
    def pwa_description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pwa_description", value)

    @_builtins.property
    @pulumi.getter(name="pwaName")
    def pwa_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Full name of the Progressive Web App. Used for the attribute `name` in `manifest.json`.
        """
        return pulumi.get(self, "pwa_name")

    @pwa_name.setter
    def pwa_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pwa_name", value)

    @_builtins.property
    @pulumi.getter(name="pwaShortName")
    def pwa_short_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Short name for Progressive Web App.
        """
        return pulumi.get(self, "pwa_short_name")

    @pwa_short_name.setter
    def pwa_short_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pwa_short_name", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application title on the sign-in and sign-up page.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "title", value)


@pulumi.type_token("gitlab:index/applicationAppearance:ApplicationAppearance")
class ApplicationAppearance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email_header_and_footer_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 footer_message: Optional[pulumi.Input[_builtins.str]] = None,
                 header_message: Optional[pulumi.Input[_builtins.str]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 member_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 message_background_color: Optional[pulumi.Input[_builtins.str]] = None,
                 message_font_color: Optional[pulumi.Input[_builtins.str]] = None,
                 new_project_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 profile_image_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_description: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_name: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_short_name: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_application_appearance`. For example:

        terraform

        import {

          to = gitlab_application_appearance.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Gitlab application appearance can be imported with the hard-coded key `gitlab`, for example:

        ```sh
        $ pulumi import gitlab:index/applicationAppearance:ApplicationAppearance example "gitlab"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Markdown text shown on the sign-in and sign-up page.
        :param pulumi.Input[_builtins.bool] email_header_and_footer_enabled: Add header and footer to all outgoing emails if enabled.
        :param pulumi.Input[_builtins.str] footer_message: Message in the system footer bar.
        :param pulumi.Input[_builtins.str] header_message: Message in the system header bar.
        :param pulumi.Input[_builtins.str] member_guidelines: Markdown text shown on the group or project member page for users with permission to change members.
        :param pulumi.Input[_builtins.str] message_background_color: Background color for the system header or footer bar, in CSS hex notation.
        :param pulumi.Input[_builtins.str] message_font_color: Font color for the system header or footer bar, in CSS hex notation.
        :param pulumi.Input[_builtins.str] new_project_guidelines: Markdown text shown on the new project page.
        :param pulumi.Input[_builtins.str] profile_image_guidelines: Markdown text shown on the profile page below the Public Avatar.
        :param pulumi.Input[_builtins.str] pwa_description: An explanation of what the Progressive Web App does. Used for the attribute `description` in `manifest.json`.
        :param pulumi.Input[_builtins.str] pwa_name: Full name of the Progressive Web App. Used for the attribute `name` in `manifest.json`.
        :param pulumi.Input[_builtins.str] pwa_short_name: Short name for Progressive Web App.
        :param pulumi.Input[_builtins.str] title: Application title on the sign-in and sign-up page.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ApplicationAppearanceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_application_appearance`. For example:

        terraform

        import {

          to = gitlab_application_appearance.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Gitlab application appearance can be imported with the hard-coded key `gitlab`, for example:

        ```sh
        $ pulumi import gitlab:index/applicationAppearance:ApplicationAppearance example "gitlab"
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationAppearanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationAppearanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email_header_and_footer_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 footer_message: Optional[pulumi.Input[_builtins.str]] = None,
                 header_message: Optional[pulumi.Input[_builtins.str]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 member_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 message_background_color: Optional[pulumi.Input[_builtins.str]] = None,
                 message_font_color: Optional[pulumi.Input[_builtins.str]] = None,
                 new_project_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 profile_image_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_description: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_name: Optional[pulumi.Input[_builtins.str]] = None,
                 pwa_short_name: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationAppearanceArgs.__new__(ApplicationAppearanceArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["email_header_and_footer_enabled"] = email_header_and_footer_enabled
            __props__.__dict__["footer_message"] = footer_message
            __props__.__dict__["header_message"] = header_message
            __props__.__dict__["keep_settings_on_destroy"] = keep_settings_on_destroy
            __props__.__dict__["member_guidelines"] = member_guidelines
            __props__.__dict__["message_background_color"] = message_background_color
            __props__.__dict__["message_font_color"] = message_font_color
            __props__.__dict__["new_project_guidelines"] = new_project_guidelines
            __props__.__dict__["profile_image_guidelines"] = profile_image_guidelines
            __props__.__dict__["pwa_description"] = pwa_description
            __props__.__dict__["pwa_name"] = pwa_name
            __props__.__dict__["pwa_short_name"] = pwa_short_name
            __props__.__dict__["title"] = title
        super(ApplicationAppearance, __self__).__init__(
            'gitlab:index/applicationAppearance:ApplicationAppearance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            email_header_and_footer_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            footer_message: Optional[pulumi.Input[_builtins.str]] = None,
            header_message: Optional[pulumi.Input[_builtins.str]] = None,
            keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            member_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
            message_background_color: Optional[pulumi.Input[_builtins.str]] = None,
            message_font_color: Optional[pulumi.Input[_builtins.str]] = None,
            new_project_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
            profile_image_guidelines: Optional[pulumi.Input[_builtins.str]] = None,
            pwa_description: Optional[pulumi.Input[_builtins.str]] = None,
            pwa_name: Optional[pulumi.Input[_builtins.str]] = None,
            pwa_short_name: Optional[pulumi.Input[_builtins.str]] = None,
            title: Optional[pulumi.Input[_builtins.str]] = None) -> 'ApplicationAppearance':
        """
        Get an existing ApplicationAppearance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Markdown text shown on the sign-in and sign-up page.
        :param pulumi.Input[_builtins.bool] email_header_and_footer_enabled: Add header and footer to all outgoing emails if enabled.
        :param pulumi.Input[_builtins.str] footer_message: Message in the system footer bar.
        :param pulumi.Input[_builtins.str] header_message: Message in the system header bar.
        :param pulumi.Input[_builtins.str] member_guidelines: Markdown text shown on the group or project member page for users with permission to change members.
        :param pulumi.Input[_builtins.str] message_background_color: Background color for the system header or footer bar, in CSS hex notation.
        :param pulumi.Input[_builtins.str] message_font_color: Font color for the system header or footer bar, in CSS hex notation.
        :param pulumi.Input[_builtins.str] new_project_guidelines: Markdown text shown on the new project page.
        :param pulumi.Input[_builtins.str] profile_image_guidelines: Markdown text shown on the profile page below the Public Avatar.
        :param pulumi.Input[_builtins.str] pwa_description: An explanation of what the Progressive Web App does. Used for the attribute `description` in `manifest.json`.
        :param pulumi.Input[_builtins.str] pwa_name: Full name of the Progressive Web App. Used for the attribute `name` in `manifest.json`.
        :param pulumi.Input[_builtins.str] pwa_short_name: Short name for Progressive Web App.
        :param pulumi.Input[_builtins.str] title: Application title on the sign-in and sign-up page.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationAppearanceState.__new__(_ApplicationAppearanceState)

        __props__.__dict__["description"] = description
        __props__.__dict__["email_header_and_footer_enabled"] = email_header_and_footer_enabled
        __props__.__dict__["footer_message"] = footer_message
        __props__.__dict__["header_message"] = header_message
        __props__.__dict__["keep_settings_on_destroy"] = keep_settings_on_destroy
        __props__.__dict__["member_guidelines"] = member_guidelines
        __props__.__dict__["message_background_color"] = message_background_color
        __props__.__dict__["message_font_color"] = message_font_color
        __props__.__dict__["new_project_guidelines"] = new_project_guidelines
        __props__.__dict__["profile_image_guidelines"] = profile_image_guidelines
        __props__.__dict__["pwa_description"] = pwa_description
        __props__.__dict__["pwa_name"] = pwa_name
        __props__.__dict__["pwa_short_name"] = pwa_short_name
        __props__.__dict__["title"] = title
        return ApplicationAppearance(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Markdown text shown on the sign-in and sign-up page.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="emailHeaderAndFooterEnabled")
    def email_header_and_footer_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Add header and footer to all outgoing emails if enabled.
        """
        return pulumi.get(self, "email_header_and_footer_enabled")

    @_builtins.property
    @pulumi.getter(name="footerMessage")
    def footer_message(self) -> pulumi.Output[_builtins.str]:
        """
        Message in the system footer bar.
        """
        return pulumi.get(self, "footer_message")

    @_builtins.property
    @pulumi.getter(name="headerMessage")
    def header_message(self) -> pulumi.Output[_builtins.str]:
        """
        Message in the system header bar.
        """
        return pulumi.get(self, "header_message")

    @_builtins.property
    @pulumi.getter(name="keepSettingsOnDestroy")
    def keep_settings_on_destroy(self) -> pulumi.Output[_builtins.bool]:
        return pulumi.get(self, "keep_settings_on_destroy")

    @_builtins.property
    @pulumi.getter(name="memberGuidelines")
    def member_guidelines(self) -> pulumi.Output[_builtins.str]:
        """
        Markdown text shown on the group or project member page for users with permission to change members.
        """
        return pulumi.get(self, "member_guidelines")

    @_builtins.property
    @pulumi.getter(name="messageBackgroundColor")
    def message_background_color(self) -> pulumi.Output[_builtins.str]:
        """
        Background color for the system header or footer bar, in CSS hex notation.
        """
        return pulumi.get(self, "message_background_color")

    @_builtins.property
    @pulumi.getter(name="messageFontColor")
    def message_font_color(self) -> pulumi.Output[_builtins.str]:
        """
        Font color for the system header or footer bar, in CSS hex notation.
        """
        return pulumi.get(self, "message_font_color")

    @_builtins.property
    @pulumi.getter(name="newProjectGuidelines")
    def new_project_guidelines(self) -> pulumi.Output[_builtins.str]:
        """
        Markdown text shown on the new project page.
        """
        return pulumi.get(self, "new_project_guidelines")

    @_builtins.property
    @pulumi.getter(name="profileImageGuidelines")
    def profile_image_guidelines(self) -> pulumi.Output[_builtins.str]:
        """
        Markdown text shown on the profile page below the Public Avatar.
        """
        return pulumi.get(self, "profile_image_guidelines")

    @_builtins.property
    @pulumi.getter(name="pwaDescription")
    def pwa_description(self) -> pulumi.Output[_builtins.str]:
        """
        An explanation of what the Progressive Web App does. Used for the attribute `description` in `manifest.json`.
        """
        return pulumi.get(self, "pwa_description")

    @_builtins.property
    @pulumi.getter(name="pwaName")
    def pwa_name(self) -> pulumi.Output[_builtins.str]:
        """
        Full name of the Progressive Web App. Used for the attribute `name` in `manifest.json`.
        """
        return pulumi.get(self, "pwa_name")

    @_builtins.property
    @pulumi.getter(name="pwaShortName")
    def pwa_short_name(self) -> pulumi.Output[_builtins.str]:
        """
        Short name for Progressive Web App.
        """
        return pulumi.get(self, "pwa_short_name")

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Output[_builtins.str]:
        """
        Application title on the sign-in and sign-up page.
        """
        return pulumi.get(self, "title")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectContainerRepositoryProtectionArgs', 'ProjectContainerRepositoryProtection']

@pulumi.input_type
class ProjectContainerRepositoryProtectionArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[_builtins.str],
                 repository_path_pattern: pulumi.Input[_builtins.str],
                 minimum_access_level_for_delete: Optional[pulumi.Input[_builtins.str]] = None,
                 minimum_access_level_for_push: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProjectContainerRepositoryProtection resource.
        :param pulumi.Input[_builtins.str] project: ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.str] repository_path_pattern: Container repository path pattern protected by the protection rule. Wildcard character * allowed. Repository path pattern should start with the project's full path
        :param pulumi.Input[_builtins.str] minimum_access_level_for_delete: Minimum GitLab access level required to delete container images in the container registry. For example maintainer, owner, admin. Must be provided when `minimum_access_level_for_push` is not set.
        :param pulumi.Input[_builtins.str] minimum_access_level_for_push: Minimum GitLab access level required to push container images to the container registry. For example maintainer, owner or admin. Must be provided when `minimum_access_level_for_delete` is not set.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "repository_path_pattern", repository_path_pattern)
        if minimum_access_level_for_delete is not None:
            pulumi.set(__self__, "minimum_access_level_for_delete", minimum_access_level_for_delete)
        if minimum_access_level_for_push is not None:
            pulumi.set(__self__, "minimum_access_level_for_push", minimum_access_level_for_push)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="repositoryPathPattern")
    def repository_path_pattern(self) -> pulumi.Input[_builtins.str]:
        """
        Container repository path pattern protected by the protection rule. Wildcard character * allowed. Repository path pattern should start with the project's full path
        """
        return pulumi.get(self, "repository_path_pattern")

    @repository_path_pattern.setter
    def repository_path_pattern(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "repository_path_pattern", value)

    @_builtins.property
    @pulumi.getter(name="minimumAccessLevelForDelete")
    def minimum_access_level_for_delete(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Minimum GitLab access level required to delete container images in the container registry. For example maintainer, owner, admin. Must be provided when `minimum_access_level_for_push` is not set.
        """
        return pulumi.get(self, "minimum_access_level_for_delete")

    @minimum_access_level_for_delete.setter
    def minimum_access_level_for_delete(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "minimum_access_level_for_delete", value)

    @_builtins.property
    @pulumi.getter(name="minimumAccessLevelForPush")
    def minimum_access_level_for_push(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Minimum GitLab access level required to push container images to the container registry. For example maintainer, owner or admin. Must be provided when `minimum_access_level_for_delete` is not set.
        """
        return pulumi.get(self, "minimum_access_level_for_push")

    @minimum_access_level_for_push.setter
    def minimum_access_level_for_push(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "minimum_access_level_for_push", value)


@pulumi.input_type
class _ProjectContainerRepositoryProtectionState:
    def __init__(__self__, *,
                 minimum_access_level_for_delete: Optional[pulumi.Input[_builtins.str]] = None,
                 minimum_access_level_for_push: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 protection_rule_id: Optional[pulumi.Input[_builtins.int]] = None,
                 repository_path_pattern: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectContainerRepositoryProtection resources.
        :param pulumi.Input[_builtins.str] minimum_access_level_for_delete: Minimum GitLab access level required to delete container images in the container registry. For example maintainer, owner, admin. Must be provided when `minimum_access_level_for_push` is not set.
        :param pulumi.Input[_builtins.str] minimum_access_level_for_push: Minimum GitLab access level required to push container images to the container registry. For example maintainer, owner or admin. Must be provided when `minimum_access_level_for_delete` is not set.
        :param pulumi.Input[_builtins.str] project: ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.int] protection_rule_id: Unique ID of the protection rule.
        :param pulumi.Input[_builtins.str] repository_path_pattern: Container repository path pattern protected by the protection rule. Wildcard character * allowed. Repository path pattern should start with the project's full path
        """
        if minimum_access_level_for_delete is not None:
            pulumi.set(__self__, "minimum_access_level_for_delete", minimum_access_level_for_delete)
        if minimum_access_level_for_push is not None:
            pulumi.set(__self__, "minimum_access_level_for_push", minimum_access_level_for_push)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if protection_rule_id is not None:
            pulumi.set(__self__, "protection_rule_id", protection_rule_id)
        if repository_path_pattern is not None:
            pulumi.set(__self__, "repository_path_pattern", repository_path_pattern)

    @_builtins.property
    @pulumi.getter(name="minimumAccessLevelForDelete")
    def minimum_access_level_for_delete(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Minimum GitLab access level required to delete container images in the container registry. For example maintainer, owner, admin. Must be provided when `minimum_access_level_for_push` is not set.
        """
        return pulumi.get(self, "minimum_access_level_for_delete")

    @minimum_access_level_for_delete.setter
    def minimum_access_level_for_delete(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "minimum_access_level_for_delete", value)

    @_builtins.property
    @pulumi.getter(name="minimumAccessLevelForPush")
    def minimum_access_level_for_push(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Minimum GitLab access level required to push container images to the container registry. For example maintainer, owner or admin. Must be provided when `minimum_access_level_for_delete` is not set.
        """
        return pulumi.get(self, "minimum_access_level_for_push")

    @minimum_access_level_for_push.setter
    def minimum_access_level_for_push(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "minimum_access_level_for_push", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="protectionRuleId")
    def protection_rule_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Unique ID of the protection rule.
        """
        return pulumi.get(self, "protection_rule_id")

    @protection_rule_id.setter
    def protection_rule_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "protection_rule_id", value)

    @_builtins.property
    @pulumi.getter(name="repositoryPathPattern")
    def repository_path_pattern(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Container repository path pattern protected by the protection rule. Wildcard character * allowed. Repository path pattern should start with the project's full path
        """
        return pulumi.get(self, "repository_path_pattern")

    @repository_path_pattern.setter
    def repository_path_pattern(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_path_pattern", value)


@pulumi.type_token("gitlab:index/projectContainerRepositoryProtection:ProjectContainerRepositoryProtection")
class ProjectContainerRepositoryProtection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 minimum_access_level_for_delete: Optional[pulumi.Input[_builtins.str]] = None,
                 minimum_access_level_for_push: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path_pattern: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectContainerRepositoryProtection` resource allows managing the lifecycle of a container repository protection rule.

        You can use a wildcard (*) to protect multiple container repositories with the same container protection rule.
        You can apply several protection rules to the same container repository. A container repository is protected if at least one protection rule matches.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/container_repository_protection_rules/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        this = gitlab.ProjectContainerRepositoryProtection("this",
            project="123",
            repository_path_pattern="my_namespace/project*",
            minimum_access_level_for_push="owner",
            minimum_access_level_for_delete="admin")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_container_repository_protection`. For example:

        terraform

        import {

          to = gitlab_project_container_repository_protection.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab project container repository protection rules can be imported using an id made up of `<project_id>:<protection_rule_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectContainerRepositoryProtection:ProjectContainerRepositoryProtection this 123:321
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] minimum_access_level_for_delete: Minimum GitLab access level required to delete container images in the container registry. For example maintainer, owner, admin. Must be provided when `minimum_access_level_for_push` is not set.
        :param pulumi.Input[_builtins.str] minimum_access_level_for_push: Minimum GitLab access level required to push container images to the container registry. For example maintainer, owner or admin. Must be provided when `minimum_access_level_for_delete` is not set.
        :param pulumi.Input[_builtins.str] project: ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.str] repository_path_pattern: Container repository path pattern protected by the protection rule. Wildcard character * allowed. Repository path pattern should start with the project's full path
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectContainerRepositoryProtectionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectContainerRepositoryProtection` resource allows managing the lifecycle of a container repository protection rule.

        You can use a wildcard (*) to protect multiple container repositories with the same container protection rule.
        You can apply several protection rules to the same container repository. A container repository is protected if at least one protection rule matches.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/container_repository_protection_rules/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        this = gitlab.ProjectContainerRepositoryProtection("this",
            project="123",
            repository_path_pattern="my_namespace/project*",
            minimum_access_level_for_push="owner",
            minimum_access_level_for_delete="admin")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_container_repository_protection`. For example:

        terraform

        import {

          to = gitlab_project_container_repository_protection.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab project container repository protection rules can be imported using an id made up of `<project_id>:<protection_rule_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectContainerRepositoryProtection:ProjectContainerRepositoryProtection this 123:321
        ```

        :param str resource_name: The name of the resource.
        :param ProjectContainerRepositoryProtectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectContainerRepositoryProtectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 minimum_access_level_for_delete: Optional[pulumi.Input[_builtins.str]] = None,
                 minimum_access_level_for_push: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path_pattern: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectContainerRepositoryProtectionArgs.__new__(ProjectContainerRepositoryProtectionArgs)

            __props__.__dict__["minimum_access_level_for_delete"] = minimum_access_level_for_delete
            __props__.__dict__["minimum_access_level_for_push"] = minimum_access_level_for_push
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if repository_path_pattern is None and not opts.urn:
                raise TypeError("Missing required property 'repository_path_pattern'")
            __props__.__dict__["repository_path_pattern"] = repository_path_pattern
            __props__.__dict__["protection_rule_id"] = None
        super(ProjectContainerRepositoryProtection, __self__).__init__(
            'gitlab:index/projectContainerRepositoryProtection:ProjectContainerRepositoryProtection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            minimum_access_level_for_delete: Optional[pulumi.Input[_builtins.str]] = None,
            minimum_access_level_for_push: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            protection_rule_id: Optional[pulumi.Input[_builtins.int]] = None,
            repository_path_pattern: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectContainerRepositoryProtection':
        """
        Get an existing ProjectContainerRepositoryProtection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] minimum_access_level_for_delete: Minimum GitLab access level required to delete container images in the container registry. For example maintainer, owner, admin. Must be provided when `minimum_access_level_for_push` is not set.
        :param pulumi.Input[_builtins.str] minimum_access_level_for_push: Minimum GitLab access level required to push container images to the container registry. For example maintainer, owner or admin. Must be provided when `minimum_access_level_for_delete` is not set.
        :param pulumi.Input[_builtins.str] project: ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.int] protection_rule_id: Unique ID of the protection rule.
        :param pulumi.Input[_builtins.str] repository_path_pattern: Container repository path pattern protected by the protection rule. Wildcard character * allowed. Repository path pattern should start with the project's full path
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectContainerRepositoryProtectionState.__new__(_ProjectContainerRepositoryProtectionState)

        __props__.__dict__["minimum_access_level_for_delete"] = minimum_access_level_for_delete
        __props__.__dict__["minimum_access_level_for_push"] = minimum_access_level_for_push
        __props__.__dict__["project"] = project
        __props__.__dict__["protection_rule_id"] = protection_rule_id
        __props__.__dict__["repository_path_pattern"] = repository_path_pattern
        return ProjectContainerRepositoryProtection(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="minimumAccessLevelForDelete")
    def minimum_access_level_for_delete(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Minimum GitLab access level required to delete container images in the container registry. For example maintainer, owner, admin. Must be provided when `minimum_access_level_for_push` is not set.
        """
        return pulumi.get(self, "minimum_access_level_for_delete")

    @_builtins.property
    @pulumi.getter(name="minimumAccessLevelForPush")
    def minimum_access_level_for_push(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Minimum GitLab access level required to push container images to the container registry. For example maintainer, owner or admin. Must be provided when `minimum_access_level_for_delete` is not set.
        """
        return pulumi.get(self, "minimum_access_level_for_push")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="protectionRuleId")
    def protection_rule_id(self) -> pulumi.Output[_builtins.int]:
        """
        Unique ID of the protection rule.
        """
        return pulumi.get(self, "protection_rule_id")

    @_builtins.property
    @pulumi.getter(name="repositoryPathPattern")
    def repository_path_pattern(self) -> pulumi.Output[_builtins.str]:
        """
        Container repository path pattern protected by the protection rule. Wildcard character * allowed. Repository path pattern should start with the project's full path
        """
        return pulumi.get(self, "repository_path_pattern")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectPushRulesInitArgs', 'ProjectPushRules']

@pulumi.input_type
class ProjectPushRulesInitArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[_builtins.str],
                 author_email_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 branch_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_committer_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 commit_committer_name_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 commit_message_negative_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_message_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 deny_delete_tag: Optional[pulumi.Input[_builtins.bool]] = None,
                 file_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 max_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 member_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_secrets: Optional[pulumi.Input[_builtins.bool]] = None,
                 reject_non_dco_commits: Optional[pulumi.Input[_builtins.bool]] = None,
                 reject_unsigned_commits: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ProjectPushRules resource.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.str] author_email_regex: All commit author emails must match this regex, e.g. `@my-company.com$`.
        :param pulumi.Input[_builtins.str] branch_name_regex: All branch names must match this regex, e.g. `(feature|hotfix)\\/*`.
        :param pulumi.Input[_builtins.bool] commit_committer_check: Users can only push commits to this repository that were committed with one of their own verified emails.
        :param pulumi.Input[_builtins.bool] commit_committer_name_check: Users can only push commits to this repository if the commit author name is consistent with their GitLab account name.
        :param pulumi.Input[_builtins.str] commit_message_negative_regex: No commit message is allowed to match this regex, e.g. `ssh\\:\\/\\/`.
        :param pulumi.Input[_builtins.str] commit_message_regex: All commit messages must match this regex, e.g. `Fixed \\d+\\..*`.
        :param pulumi.Input[_builtins.bool] deny_delete_tag: Deny deleting a tag.
        :param pulumi.Input[_builtins.str] file_name_regex: All committed filenames must not match this regex, e.g. `(jar|exe)$`.
        :param pulumi.Input[_builtins.int] max_file_size: Maximum file size (MB).
        :param pulumi.Input[_builtins.bool] member_check: Restrict commits by author (email) to existing GitLab users.
        :param pulumi.Input[_builtins.bool] prevent_secrets: GitLab will reject any files that are likely to contain secrets.
        :param pulumi.Input[_builtins.bool] reject_non_dco_commits: Reject commit when it’s not DCO certified.
        :param pulumi.Input[_builtins.bool] reject_unsigned_commits: Reject commit when it’s not signed.
        """
        pulumi.set(__self__, "project", project)
        if author_email_regex is not None:
            pulumi.set(__self__, "author_email_regex", author_email_regex)
        if branch_name_regex is not None:
            pulumi.set(__self__, "branch_name_regex", branch_name_regex)
        if commit_committer_check is not None:
            pulumi.set(__self__, "commit_committer_check", commit_committer_check)
        if commit_committer_name_check is not None:
            pulumi.set(__self__, "commit_committer_name_check", commit_committer_name_check)
        if commit_message_negative_regex is not None:
            pulumi.set(__self__, "commit_message_negative_regex", commit_message_negative_regex)
        if commit_message_regex is not None:
            pulumi.set(__self__, "commit_message_regex", commit_message_regex)
        if deny_delete_tag is not None:
            pulumi.set(__self__, "deny_delete_tag", deny_delete_tag)
        if file_name_regex is not None:
            pulumi.set(__self__, "file_name_regex", file_name_regex)
        if max_file_size is not None:
            pulumi.set(__self__, "max_file_size", max_file_size)
        if member_check is not None:
            pulumi.set(__self__, "member_check", member_check)
        if prevent_secrets is not None:
            pulumi.set(__self__, "prevent_secrets", prevent_secrets)
        if reject_non_dco_commits is not None:
            pulumi.set(__self__, "reject_non_dco_commits", reject_non_dco_commits)
        if reject_unsigned_commits is not None:
            pulumi.set(__self__, "reject_unsigned_commits", reject_unsigned_commits)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="authorEmailRegex")
    def author_email_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All commit author emails must match this regex, e.g. `@my-company.com$`.
        """
        return pulumi.get(self, "author_email_regex")

    @author_email_regex.setter
    def author_email_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "author_email_regex", value)

    @_builtins.property
    @pulumi.getter(name="branchNameRegex")
    def branch_name_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All branch names must match this regex, e.g. `(feature|hotfix)\\/*`.
        """
        return pulumi.get(self, "branch_name_regex")

    @branch_name_regex.setter
    def branch_name_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "branch_name_regex", value)

    @_builtins.property
    @pulumi.getter(name="commitCommitterCheck")
    def commit_committer_check(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Users can only push commits to this repository that were committed with one of their own verified emails.
        """
        return pulumi.get(self, "commit_committer_check")

    @commit_committer_check.setter
    def commit_committer_check(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "commit_committer_check", value)

    @_builtins.property
    @pulumi.getter(name="commitCommitterNameCheck")
    def commit_committer_name_check(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Users can only push commits to this repository if the commit author name is consistent with their GitLab account name.
        """
        return pulumi.get(self, "commit_committer_name_check")

    @commit_committer_name_check.setter
    def commit_committer_name_check(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "commit_committer_name_check", value)

    @_builtins.property
    @pulumi.getter(name="commitMessageNegativeRegex")
    def commit_message_negative_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        No commit message is allowed to match this regex, e.g. `ssh\\:\\/\\/`.
        """
        return pulumi.get(self, "commit_message_negative_regex")

    @commit_message_negative_regex.setter
    def commit_message_negative_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "commit_message_negative_regex", value)

    @_builtins.property
    @pulumi.getter(name="commitMessageRegex")
    def commit_message_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All commit messages must match this regex, e.g. `Fixed \\d+\\..*`.
        """
        return pulumi.get(self, "commit_message_regex")

    @commit_message_regex.setter
    def commit_message_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "commit_message_regex", value)

    @_builtins.property
    @pulumi.getter(name="denyDeleteTag")
    def deny_delete_tag(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Deny deleting a tag.
        """
        return pulumi.get(self, "deny_delete_tag")

    @deny_delete_tag.setter
    def deny_delete_tag(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "deny_delete_tag", value)

    @_builtins.property
    @pulumi.getter(name="fileNameRegex")
    def file_name_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All committed filenames must not match this regex, e.g. `(jar|exe)$`.
        """
        return pulumi.get(self, "file_name_regex")

    @file_name_regex.setter
    def file_name_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "file_name_regex", value)

    @_builtins.property
    @pulumi.getter(name="maxFileSize")
    def max_file_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum file size (MB).
        """
        return pulumi.get(self, "max_file_size")

    @max_file_size.setter
    def max_file_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_file_size", value)

    @_builtins.property
    @pulumi.getter(name="memberCheck")
    def member_check(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Restrict commits by author (email) to existing GitLab users.
        """
        return pulumi.get(self, "member_check")

    @member_check.setter
    def member_check(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "member_check", value)

    @_builtins.property
    @pulumi.getter(name="preventSecrets")
    def prevent_secrets(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        GitLab will reject any files that are likely to contain secrets.
        """
        return pulumi.get(self, "prevent_secrets")

    @prevent_secrets.setter
    def prevent_secrets(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "prevent_secrets", value)

    @_builtins.property
    @pulumi.getter(name="rejectNonDcoCommits")
    def reject_non_dco_commits(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Reject commit when it’s not DCO certified.
        """
        return pulumi.get(self, "reject_non_dco_commits")

    @reject_non_dco_commits.setter
    def reject_non_dco_commits(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "reject_non_dco_commits", value)

    @_builtins.property
    @pulumi.getter(name="rejectUnsignedCommits")
    def reject_unsigned_commits(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Reject commit when it’s not signed.
        """
        return pulumi.get(self, "reject_unsigned_commits")

    @reject_unsigned_commits.setter
    def reject_unsigned_commits(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "reject_unsigned_commits", value)


@pulumi.input_type
class _ProjectPushRulesState:
    def __init__(__self__, *,
                 author_email_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 branch_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_committer_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 commit_committer_name_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 commit_message_negative_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_message_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 deny_delete_tag: Optional[pulumi.Input[_builtins.bool]] = None,
                 file_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 max_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 member_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_secrets: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 reject_non_dco_commits: Optional[pulumi.Input[_builtins.bool]] = None,
                 reject_unsigned_commits: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering ProjectPushRules resources.
        :param pulumi.Input[_builtins.str] author_email_regex: All commit author emails must match this regex, e.g. `@my-company.com$`.
        :param pulumi.Input[_builtins.str] branch_name_regex: All branch names must match this regex, e.g. `(feature|hotfix)\\/*`.
        :param pulumi.Input[_builtins.bool] commit_committer_check: Users can only push commits to this repository that were committed with one of their own verified emails.
        :param pulumi.Input[_builtins.bool] commit_committer_name_check: Users can only push commits to this repository if the commit author name is consistent with their GitLab account name.
        :param pulumi.Input[_builtins.str] commit_message_negative_regex: No commit message is allowed to match this regex, e.g. `ssh\\:\\/\\/`.
        :param pulumi.Input[_builtins.str] commit_message_regex: All commit messages must match this regex, e.g. `Fixed \\d+\\..*`.
        :param pulumi.Input[_builtins.bool] deny_delete_tag: Deny deleting a tag.
        :param pulumi.Input[_builtins.str] file_name_regex: All committed filenames must not match this regex, e.g. `(jar|exe)$`.
        :param pulumi.Input[_builtins.int] max_file_size: Maximum file size (MB).
        :param pulumi.Input[_builtins.bool] member_check: Restrict commits by author (email) to existing GitLab users.
        :param pulumi.Input[_builtins.bool] prevent_secrets: GitLab will reject any files that are likely to contain secrets.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.bool] reject_non_dco_commits: Reject commit when it’s not DCO certified.
        :param pulumi.Input[_builtins.bool] reject_unsigned_commits: Reject commit when it’s not signed.
        """
        if author_email_regex is not None:
            pulumi.set(__self__, "author_email_regex", author_email_regex)
        if branch_name_regex is not None:
            pulumi.set(__self__, "branch_name_regex", branch_name_regex)
        if commit_committer_check is not None:
            pulumi.set(__self__, "commit_committer_check", commit_committer_check)
        if commit_committer_name_check is not None:
            pulumi.set(__self__, "commit_committer_name_check", commit_committer_name_check)
        if commit_message_negative_regex is not None:
            pulumi.set(__self__, "commit_message_negative_regex", commit_message_negative_regex)
        if commit_message_regex is not None:
            pulumi.set(__self__, "commit_message_regex", commit_message_regex)
        if deny_delete_tag is not None:
            pulumi.set(__self__, "deny_delete_tag", deny_delete_tag)
        if file_name_regex is not None:
            pulumi.set(__self__, "file_name_regex", file_name_regex)
        if max_file_size is not None:
            pulumi.set(__self__, "max_file_size", max_file_size)
        if member_check is not None:
            pulumi.set(__self__, "member_check", member_check)
        if prevent_secrets is not None:
            pulumi.set(__self__, "prevent_secrets", prevent_secrets)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if reject_non_dco_commits is not None:
            pulumi.set(__self__, "reject_non_dco_commits", reject_non_dco_commits)
        if reject_unsigned_commits is not None:
            pulumi.set(__self__, "reject_unsigned_commits", reject_unsigned_commits)

    @_builtins.property
    @pulumi.getter(name="authorEmailRegex")
    def author_email_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All commit author emails must match this regex, e.g. `@my-company.com$`.
        """
        return pulumi.get(self, "author_email_regex")

    @author_email_regex.setter
    def author_email_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "author_email_regex", value)

    @_builtins.property
    @pulumi.getter(name="branchNameRegex")
    def branch_name_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All branch names must match this regex, e.g. `(feature|hotfix)\\/*`.
        """
        return pulumi.get(self, "branch_name_regex")

    @branch_name_regex.setter
    def branch_name_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "branch_name_regex", value)

    @_builtins.property
    @pulumi.getter(name="commitCommitterCheck")
    def commit_committer_check(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Users can only push commits to this repository that were committed with one of their own verified emails.
        """
        return pulumi.get(self, "commit_committer_check")

    @commit_committer_check.setter
    def commit_committer_check(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "commit_committer_check", value)

    @_builtins.property
    @pulumi.getter(name="commitCommitterNameCheck")
    def commit_committer_name_check(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Users can only push commits to this repository if the commit author name is consistent with their GitLab account name.
        """
        return pulumi.get(self, "commit_committer_name_check")

    @commit_committer_name_check.setter
    def commit_committer_name_check(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "commit_committer_name_check", value)

    @_builtins.property
    @pulumi.getter(name="commitMessageNegativeRegex")
    def commit_message_negative_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        No commit message is allowed to match this regex, e.g. `ssh\\:\\/\\/`.
        """
        return pulumi.get(self, "commit_message_negative_regex")

    @commit_message_negative_regex.setter
    def commit_message_negative_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "commit_message_negative_regex", value)

    @_builtins.property
    @pulumi.getter(name="commitMessageRegex")
    def commit_message_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All commit messages must match this regex, e.g. `Fixed \\d+\\..*`.
        """
        return pulumi.get(self, "commit_message_regex")

    @commit_message_regex.setter
    def commit_message_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "commit_message_regex", value)

    @_builtins.property
    @pulumi.getter(name="denyDeleteTag")
    def deny_delete_tag(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Deny deleting a tag.
        """
        return pulumi.get(self, "deny_delete_tag")

    @deny_delete_tag.setter
    def deny_delete_tag(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "deny_delete_tag", value)

    @_builtins.property
    @pulumi.getter(name="fileNameRegex")
    def file_name_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        All committed filenames must not match this regex, e.g. `(jar|exe)$`.
        """
        return pulumi.get(self, "file_name_regex")

    @file_name_regex.setter
    def file_name_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "file_name_regex", value)

    @_builtins.property
    @pulumi.getter(name="maxFileSize")
    def max_file_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum file size (MB).
        """
        return pulumi.get(self, "max_file_size")

    @max_file_size.setter
    def max_file_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_file_size", value)

    @_builtins.property
    @pulumi.getter(name="memberCheck")
    def member_check(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Restrict commits by author (email) to existing GitLab users.
        """
        return pulumi.get(self, "member_check")

    @member_check.setter
    def member_check(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "member_check", value)

    @_builtins.property
    @pulumi.getter(name="preventSecrets")
    def prevent_secrets(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        GitLab will reject any files that are likely to contain secrets.
        """
        return pulumi.get(self, "prevent_secrets")

    @prevent_secrets.setter
    def prevent_secrets(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "prevent_secrets", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="rejectNonDcoCommits")
    def reject_non_dco_commits(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Reject commit when it’s not DCO certified.
        """
        return pulumi.get(self, "reject_non_dco_commits")

    @reject_non_dco_commits.setter
    def reject_non_dco_commits(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "reject_non_dco_commits", value)

    @_builtins.property
    @pulumi.getter(name="rejectUnsignedCommits")
    def reject_unsigned_commits(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Reject commit when it’s not signed.
        """
        return pulumi.get(self, "reject_unsigned_commits")

    @reject_unsigned_commits.setter
    def reject_unsigned_commits(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "reject_unsigned_commits", value)


@pulumi.type_token("gitlab:index/projectPushRules:ProjectPushRules")
class ProjectPushRules(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 author_email_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 branch_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_committer_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 commit_committer_name_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 commit_message_negative_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_message_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 deny_delete_tag: Optional[pulumi.Input[_builtins.bool]] = None,
                 file_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 max_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 member_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_secrets: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 reject_non_dco_commits: Optional[pulumi.Input[_builtins.bool]] = None,
                 reject_unsigned_commits: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        sample = gitlab.ProjectPushRules("sample",
            project="42",
            author_email_regex="@gitlab.com$",
            branch_name_regex="(feat|fix)\\\\/*",
            commit_committer_check=True,
            commit_committer_name_check=True,
            commit_message_negative_regex="ssh\\\\:\\\\/\\\\/",
            commit_message_regex="(feat|fix):.*",
            deny_delete_tag=False,
            file_name_regex="(jar|exe)$",
            max_file_size=4,
            member_check=True,
            prevent_secrets=True,
            reject_unsigned_commits=False)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_push_rules`. For example:

        terraform

        import {

          to = gitlab_project_push_rules.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Gitlab project push rules can be imported with a key composed of `<project_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectPushRules:ProjectPushRules sample "42"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] author_email_regex: All commit author emails must match this regex, e.g. `@my-company.com$`.
        :param pulumi.Input[_builtins.str] branch_name_regex: All branch names must match this regex, e.g. `(feature|hotfix)\\/*`.
        :param pulumi.Input[_builtins.bool] commit_committer_check: Users can only push commits to this repository that were committed with one of their own verified emails.
        :param pulumi.Input[_builtins.bool] commit_committer_name_check: Users can only push commits to this repository if the commit author name is consistent with their GitLab account name.
        :param pulumi.Input[_builtins.str] commit_message_negative_regex: No commit message is allowed to match this regex, e.g. `ssh\\:\\/\\/`.
        :param pulumi.Input[_builtins.str] commit_message_regex: All commit messages must match this regex, e.g. `Fixed \\d+\\..*`.
        :param pulumi.Input[_builtins.bool] deny_delete_tag: Deny deleting a tag.
        :param pulumi.Input[_builtins.str] file_name_regex: All committed filenames must not match this regex, e.g. `(jar|exe)$`.
        :param pulumi.Input[_builtins.int] max_file_size: Maximum file size (MB).
        :param pulumi.Input[_builtins.bool] member_check: Restrict commits by author (email) to existing GitLab users.
        :param pulumi.Input[_builtins.bool] prevent_secrets: GitLab will reject any files that are likely to contain secrets.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.bool] reject_non_dco_commits: Reject commit when it’s not DCO certified.
        :param pulumi.Input[_builtins.bool] reject_unsigned_commits: Reject commit when it’s not signed.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectPushRulesInitArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        sample = gitlab.ProjectPushRules("sample",
            project="42",
            author_email_regex="@gitlab.com$",
            branch_name_regex="(feat|fix)\\\\/*",
            commit_committer_check=True,
            commit_committer_name_check=True,
            commit_message_negative_regex="ssh\\\\:\\\\/\\\\/",
            commit_message_regex="(feat|fix):.*",
            deny_delete_tag=False,
            file_name_regex="(jar|exe)$",
            max_file_size=4,
            member_check=True,
            prevent_secrets=True,
            reject_unsigned_commits=False)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_push_rules`. For example:

        terraform

        import {

          to = gitlab_project_push_rules.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Gitlab project push rules can be imported with a key composed of `<project_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectPushRules:ProjectPushRules sample "42"
        ```

        :param str resource_name: The name of the resource.
        :param ProjectPushRulesInitArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectPushRulesInitArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 author_email_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 branch_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_committer_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 commit_committer_name_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 commit_message_negative_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 commit_message_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 deny_delete_tag: Optional[pulumi.Input[_builtins.bool]] = None,
                 file_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 max_file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 member_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_secrets: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 reject_non_dco_commits: Optional[pulumi.Input[_builtins.bool]] = None,
                 reject_unsigned_commits: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectPushRulesInitArgs.__new__(ProjectPushRulesInitArgs)

            __props__.__dict__["author_email_regex"] = author_email_regex
            __props__.__dict__["branch_name_regex"] = branch_name_regex
            __props__.__dict__["commit_committer_check"] = commit_committer_check
            __props__.__dict__["commit_committer_name_check"] = commit_committer_name_check
            __props__.__dict__["commit_message_negative_regex"] = commit_message_negative_regex
            __props__.__dict__["commit_message_regex"] = commit_message_regex
            __props__.__dict__["deny_delete_tag"] = deny_delete_tag
            __props__.__dict__["file_name_regex"] = file_name_regex
            __props__.__dict__["max_file_size"] = max_file_size
            __props__.__dict__["member_check"] = member_check
            __props__.__dict__["prevent_secrets"] = prevent_secrets
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["reject_non_dco_commits"] = reject_non_dco_commits
            __props__.__dict__["reject_unsigned_commits"] = reject_unsigned_commits
        super(ProjectPushRules, __self__).__init__(
            'gitlab:index/projectPushRules:ProjectPushRules',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            author_email_regex: Optional[pulumi.Input[_builtins.str]] = None,
            branch_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
            commit_committer_check: Optional[pulumi.Input[_builtins.bool]] = None,
            commit_committer_name_check: Optional[pulumi.Input[_builtins.bool]] = None,
            commit_message_negative_regex: Optional[pulumi.Input[_builtins.str]] = None,
            commit_message_regex: Optional[pulumi.Input[_builtins.str]] = None,
            deny_delete_tag: Optional[pulumi.Input[_builtins.bool]] = None,
            file_name_regex: Optional[pulumi.Input[_builtins.str]] = None,
            max_file_size: Optional[pulumi.Input[_builtins.int]] = None,
            member_check: Optional[pulumi.Input[_builtins.bool]] = None,
            prevent_secrets: Optional[pulumi.Input[_builtins.bool]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            reject_non_dco_commits: Optional[pulumi.Input[_builtins.bool]] = None,
            reject_unsigned_commits: Optional[pulumi.Input[_builtins.bool]] = None) -> 'ProjectPushRules':
        """
        Get an existing ProjectPushRules resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] author_email_regex: All commit author emails must match this regex, e.g. `@my-company.com$`.
        :param pulumi.Input[_builtins.str] branch_name_regex: All branch names must match this regex, e.g. `(feature|hotfix)\\/*`.
        :param pulumi.Input[_builtins.bool] commit_committer_check: Users can only push commits to this repository that were committed with one of their own verified emails.
        :param pulumi.Input[_builtins.bool] commit_committer_name_check: Users can only push commits to this repository if the commit author name is consistent with their GitLab account name.
        :param pulumi.Input[_builtins.str] commit_message_negative_regex: No commit message is allowed to match this regex, e.g. `ssh\\:\\/\\/`.
        :param pulumi.Input[_builtins.str] commit_message_regex: All commit messages must match this regex, e.g. `Fixed \\d+\\..*`.
        :param pulumi.Input[_builtins.bool] deny_delete_tag: Deny deleting a tag.
        :param pulumi.Input[_builtins.str] file_name_regex: All committed filenames must not match this regex, e.g. `(jar|exe)$`.
        :param pulumi.Input[_builtins.int] max_file_size: Maximum file size (MB).
        :param pulumi.Input[_builtins.bool] member_check: Restrict commits by author (email) to existing GitLab users.
        :param pulumi.Input[_builtins.bool] prevent_secrets: GitLab will reject any files that are likely to contain secrets.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.bool] reject_non_dco_commits: Reject commit when it’s not DCO certified.
        :param pulumi.Input[_builtins.bool] reject_unsigned_commits: Reject commit when it’s not signed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectPushRulesState.__new__(_ProjectPushRulesState)

        __props__.__dict__["author_email_regex"] = author_email_regex
        __props__.__dict__["branch_name_regex"] = branch_name_regex
        __props__.__dict__["commit_committer_check"] = commit_committer_check
        __props__.__dict__["commit_committer_name_check"] = commit_committer_name_check
        __props__.__dict__["commit_message_negative_regex"] = commit_message_negative_regex
        __props__.__dict__["commit_message_regex"] = commit_message_regex
        __props__.__dict__["deny_delete_tag"] = deny_delete_tag
        __props__.__dict__["file_name_regex"] = file_name_regex
        __props__.__dict__["max_file_size"] = max_file_size
        __props__.__dict__["member_check"] = member_check
        __props__.__dict__["prevent_secrets"] = prevent_secrets
        __props__.__dict__["project"] = project
        __props__.__dict__["reject_non_dco_commits"] = reject_non_dco_commits
        __props__.__dict__["reject_unsigned_commits"] = reject_unsigned_commits
        return ProjectPushRules(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="authorEmailRegex")
    def author_email_regex(self) -> pulumi.Output[_builtins.str]:
        """
        All commit author emails must match this regex, e.g. `@my-company.com$`.
        """
        return pulumi.get(self, "author_email_regex")

    @_builtins.property
    @pulumi.getter(name="branchNameRegex")
    def branch_name_regex(self) -> pulumi.Output[_builtins.str]:
        """
        All branch names must match this regex, e.g. `(feature|hotfix)\\/*`.
        """
        return pulumi.get(self, "branch_name_regex")

    @_builtins.property
    @pulumi.getter(name="commitCommitterCheck")
    def commit_committer_check(self) -> pulumi.Output[_builtins.bool]:
        """
        Users can only push commits to this repository that were committed with one of their own verified emails.
        """
        return pulumi.get(self, "commit_committer_check")

    @_builtins.property
    @pulumi.getter(name="commitCommitterNameCheck")
    def commit_committer_name_check(self) -> pulumi.Output[_builtins.bool]:
        """
        Users can only push commits to this repository if the commit author name is consistent with their GitLab account name.
        """
        return pulumi.get(self, "commit_committer_name_check")

    @_builtins.property
    @pulumi.getter(name="commitMessageNegativeRegex")
    def commit_message_negative_regex(self) -> pulumi.Output[_builtins.str]:
        """
        No commit message is allowed to match this regex, e.g. `ssh\\:\\/\\/`.
        """
        return pulumi.get(self, "commit_message_negative_regex")

    @_builtins.property
    @pulumi.getter(name="commitMessageRegex")
    def commit_message_regex(self) -> pulumi.Output[_builtins.str]:
        """
        All commit messages must match this regex, e.g. `Fixed \\d+\\..*`.
        """
        return pulumi.get(self, "commit_message_regex")

    @_builtins.property
    @pulumi.getter(name="denyDeleteTag")
    def deny_delete_tag(self) -> pulumi.Output[_builtins.bool]:
        """
        Deny deleting a tag.
        """
        return pulumi.get(self, "deny_delete_tag")

    @_builtins.property
    @pulumi.getter(name="fileNameRegex")
    def file_name_regex(self) -> pulumi.Output[_builtins.str]:
        """
        All committed filenames must not match this regex, e.g. `(jar|exe)$`.
        """
        return pulumi.get(self, "file_name_regex")

    @_builtins.property
    @pulumi.getter(name="maxFileSize")
    def max_file_size(self) -> pulumi.Output[_builtins.int]:
        """
        Maximum file size (MB).
        """
        return pulumi.get(self, "max_file_size")

    @_builtins.property
    @pulumi.getter(name="memberCheck")
    def member_check(self) -> pulumi.Output[_builtins.bool]:
        """
        Restrict commits by author (email) to existing GitLab users.
        """
        return pulumi.get(self, "member_check")

    @_builtins.property
    @pulumi.getter(name="preventSecrets")
    def prevent_secrets(self) -> pulumi.Output[_builtins.bool]:
        """
        GitLab will reject any files that are likely to contain secrets.
        """
        return pulumi.get(self, "prevent_secrets")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="rejectNonDcoCommits")
    def reject_non_dco_commits(self) -> pulumi.Output[_builtins.bool]:
        """
        Reject commit when it’s not DCO certified.
        """
        return pulumi.get(self, "reject_non_dco_commits")

    @_builtins.property
    @pulumi.getter(name="rejectUnsignedCommits")
    def reject_unsigned_commits(self) -> pulumi.Output[_builtins.bool]:
        """
        Reject commit when it’s not signed.
        """
        return pulumi.get(self, "reject_unsigned_commits")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RunnerArgs', 'Runner']

@pulumi.input_type
class RunnerArgs:
    def __init__(__self__, *,
                 registration_token: pulumi.Input[_builtins.str],
                 access_level: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 locked: Optional[pulumi.Input[_builtins.bool]] = None,
                 maintenance_note: Optional[pulumi.Input[_builtins.str]] = None,
                 maximum_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 paused: Optional[pulumi.Input[_builtins.bool]] = None,
                 run_untagged: Optional[pulumi.Input[_builtins.bool]] = None,
                 tag_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Runner resource.
        :param pulumi.Input[_builtins.str] registration_token: The registration token used to register the runner.
        :param pulumi.Input[_builtins.str] access_level: The access_level of the runner. Valid values are: `not_protected`, `ref_protected`.
        :param pulumi.Input[_builtins.str] description: The runner's description.
        :param pulumi.Input[_builtins.bool] locked: Whether the runner should be locked for current project.
        :param pulumi.Input[_builtins.str] maintenance_note: Free-form maintenance notes for the runner (1024 characters).
        :param pulumi.Input[_builtins.int] maximum_timeout: Maximum timeout set when this runner handles the job.
        :param pulumi.Input[_builtins.bool] paused: Whether the runner should ignore new jobs.
        :param pulumi.Input[_builtins.bool] run_untagged: Whether the runner should handle untagged jobs.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tag_lists: List of runner’s tags.
        """
        pulumi.set(__self__, "registration_token", registration_token)
        if access_level is not None:
            pulumi.set(__self__, "access_level", access_level)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if locked is not None:
            pulumi.set(__self__, "locked", locked)
        if maintenance_note is not None:
            pulumi.set(__self__, "maintenance_note", maintenance_note)
        if maximum_timeout is not None:
            pulumi.set(__self__, "maximum_timeout", maximum_timeout)
        if paused is not None:
            pulumi.set(__self__, "paused", paused)
        if run_untagged is not None:
            pulumi.set(__self__, "run_untagged", run_untagged)
        if tag_lists is not None:
            pulumi.set(__self__, "tag_lists", tag_lists)

    @_builtins.property
    @pulumi.getter(name="registrationToken")
    def registration_token(self) -> pulumi.Input[_builtins.str]:
        """
        The registration token used to register the runner.
        """
        return pulumi.get(self, "registration_token")

    @registration_token.setter
    def registration_token(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "registration_token", value)

    @_builtins.property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access_level of the runner. Valid values are: `not_protected`, `ref_protected`.
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_level", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The runner's description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def locked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the runner should be locked for current project.
        """
        return pulumi.get(self, "locked")

    @locked.setter
    def locked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "locked", value)

    @_builtins.property
    @pulumi.getter(name="maintenanceNote")
    def maintenance_note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Free-form maintenance notes for the runner (1024 characters).
        """
        return pulumi.get(self, "maintenance_note")

    @maintenance_note.setter
    def maintenance_note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maintenance_note", value)

    @_builtins.property
    @pulumi.getter(name="maximumTimeout")
    def maximum_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum timeout set when this runner handles the job.
        """
        return pulumi.get(self, "maximum_timeout")

    @maximum_timeout.setter
    def maximum_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "maximum_timeout", value)

    @_builtins.property
    @pulumi.getter
    def paused(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the runner should ignore new jobs.
        """
        return pulumi.get(self, "paused")

    @paused.setter
    def paused(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "paused", value)

    @_builtins.property
    @pulumi.getter(name="runUntagged")
    def run_untagged(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the runner should handle untagged jobs.
        """
        return pulumi.get(self, "run_untagged")

    @run_untagged.setter
    def run_untagged(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "run_untagged", value)

    @_builtins.property
    @pulumi.getter(name="tagLists")
    def tag_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of runner’s tags.
        """
        return pulumi.get(self, "tag_lists")

    @tag_lists.setter
    def tag_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tag_lists", value)


@pulumi.input_type
class _RunnerState:
    def __init__(__self__, *,
                 access_level: Optional[pulumi.Input[_builtins.str]] = None,
                 authentication_token: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 locked: Optional[pulumi.Input[_builtins.bool]] = None,
                 maintenance_note: Optional[pulumi.Input[_builtins.str]] = None,
                 maximum_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 paused: Optional[pulumi.Input[_builtins.bool]] = None,
                 registration_token: Optional[pulumi.Input[_builtins.str]] = None,
                 run_untagged: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tag_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Runner resources.
        :param pulumi.Input[_builtins.str] access_level: The access_level of the runner. Valid values are: `not_protected`, `ref_protected`.
        :param pulumi.Input[_builtins.str] authentication_token: The authentication token used for building a config.toml file. This value is not present when imported.
        :param pulumi.Input[_builtins.str] description: The runner's description.
        :param pulumi.Input[_builtins.bool] locked: Whether the runner should be locked for current project.
        :param pulumi.Input[_builtins.str] maintenance_note: Free-form maintenance notes for the runner (1024 characters).
        :param pulumi.Input[_builtins.int] maximum_timeout: Maximum timeout set when this runner handles the job.
        :param pulumi.Input[_builtins.bool] paused: Whether the runner should ignore new jobs.
        :param pulumi.Input[_builtins.str] registration_token: The registration token used to register the runner.
        :param pulumi.Input[_builtins.bool] run_untagged: Whether the runner should handle untagged jobs.
        :param pulumi.Input[_builtins.str] status: The status of runners to show, one of: online and offline. active and paused are also possible values
               			              which were deprecated in GitLab 14.8 and will be removed in GitLab 16.0.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tag_lists: List of runner’s tags.
        """
        if access_level is not None:
            pulumi.set(__self__, "access_level", access_level)
        if authentication_token is not None:
            pulumi.set(__self__, "authentication_token", authentication_token)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if locked is not None:
            pulumi.set(__self__, "locked", locked)
        if maintenance_note is not None:
            pulumi.set(__self__, "maintenance_note", maintenance_note)
        if maximum_timeout is not None:
            pulumi.set(__self__, "maximum_timeout", maximum_timeout)
        if paused is not None:
            pulumi.set(__self__, "paused", paused)
        if registration_token is not None:
            pulumi.set(__self__, "registration_token", registration_token)
        if run_untagged is not None:
            pulumi.set(__self__, "run_untagged", run_untagged)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tag_lists is not None:
            pulumi.set(__self__, "tag_lists", tag_lists)

    @_builtins.property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access_level of the runner. Valid values are: `not_protected`, `ref_protected`.
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_level", value)

    @_builtins.property
    @pulumi.getter(name="authenticationToken")
    def authentication_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The authentication token used for building a config.toml file. This value is not present when imported.
        """
        return pulumi.get(self, "authentication_token")

    @authentication_token.setter
    def authentication_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "authentication_token", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The runner's description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def locked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the runner should be locked for current project.
        """
        return pulumi.get(self, "locked")

    @locked.setter
    def locked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "locked", value)

    @_builtins.property
    @pulumi.getter(name="maintenanceNote")
    def maintenance_note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Free-form maintenance notes for the runner (1024 characters).
        """
        return pulumi.get(self, "maintenance_note")

    @maintenance_note.setter
    def maintenance_note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maintenance_note", value)

    @_builtins.property
    @pulumi.getter(name="maximumTimeout")
    def maximum_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Maximum timeout set when this runner handles the job.
        """
        return pulumi.get(self, "maximum_timeout")

    @maximum_timeout.setter
    def maximum_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "maximum_timeout", value)

    @_builtins.property
    @pulumi.getter
    def paused(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the runner should ignore new jobs.
        """
        return pulumi.get(self, "paused")

    @paused.setter
    def paused(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "paused", value)

    @_builtins.property
    @pulumi.getter(name="registrationToken")
    def registration_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The registration token used to register the runner.
        """
        return pulumi.get(self, "registration_token")

    @registration_token.setter
    def registration_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "registration_token", value)

    @_builtins.property
    @pulumi.getter(name="runUntagged")
    def run_untagged(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the runner should handle untagged jobs.
        """
        return pulumi.get(self, "run_untagged")

    @run_untagged.setter
    def run_untagged(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "run_untagged", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of runners to show, one of: online and offline. active and paused are also possible values
        			              which were deprecated in GitLab 14.8 and will be removed in GitLab 16.0.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="tagLists")
    def tag_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of runner’s tags.
        """
        return pulumi.get(self, "tag_lists")

    @tag_lists.setter
    def tag_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tag_lists", value)


@pulumi.type_token("gitlab:index/runner:Runner")
class Runner(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 locked: Optional[pulumi.Input[_builtins.bool]] = None,
                 maintenance_note: Optional[pulumi.Input[_builtins.str]] = None,
                 maximum_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 paused: Optional[pulumi.Input[_builtins.bool]] = None,
                 registration_token: Optional[pulumi.Input[_builtins.str]] = None,
                 run_untagged: Optional[pulumi.Input[_builtins.bool]] = None,
                 tag_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        The `Runner` resource allows to manage the lifecycle of a runner.

        A runner can either be registered at an instance level or group level.
        The runner will be registered at a group level if the token used is from a group, or at an instance level if the token used is for the instance.

        ~ > Using this resource will register a runner using the deprecated `registration_token` flow. To use the new `authentication_token` flow instead,
        use the `UserRunner` resource!

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/runners/#register-a-new-runner)

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_runner`. For example:

        terraform

        import {

          to = gitlab_runner.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        A GitLab Runner can be imported using the runner's ID, eg

        ```sh
        $ pulumi import gitlab:index/runner:Runner this 1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_level: The access_level of the runner. Valid values are: `not_protected`, `ref_protected`.
        :param pulumi.Input[_builtins.str] description: The runner's description.
        :param pulumi.Input[_builtins.bool] locked: Whether the runner should be locked for current project.
        :param pulumi.Input[_builtins.str] maintenance_note: Free-form maintenance notes for the runner (1024 characters).
        :param pulumi.Input[_builtins.int] maximum_timeout: Maximum timeout set when this runner handles the job.
        :param pulumi.Input[_builtins.bool] paused: Whether the runner should ignore new jobs.
        :param pulumi.Input[_builtins.str] registration_token: The registration token used to register the runner.
        :param pulumi.Input[_builtins.bool] run_untagged: Whether the runner should handle untagged jobs.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tag_lists: List of runner’s tags.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RunnerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `Runner` resource allows to manage the lifecycle of a runner.

        A runner can either be registered at an instance level or group level.
        The runner will be registered at a group level if the token used is from a group, or at an instance level if the token used is for the instance.

        ~ > Using this resource will register a runner using the deprecated `registration_token` flow. To use the new `authentication_token` flow instead,
        use the `UserRunner` resource!

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/runners/#register-a-new-runner)

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_runner`. For example:

        terraform

        import {

          to = gitlab_runner.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        A GitLab Runner can be imported using the runner's ID, eg

        ```sh
        $ pulumi import gitlab:index/runner:Runner this 1
        ```

        :param str resource_name: The name of the resource.
        :param RunnerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RunnerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 locked: Optional[pulumi.Input[_builtins.bool]] = None,
                 maintenance_note: Optional[pulumi.Input[_builtins.str]] = None,
                 maximum_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 paused: Optional[pulumi.Input[_builtins.bool]] = None,
                 registration_token: Optional[pulumi.Input[_builtins.str]] = None,
                 run_untagged: Optional[pulumi.Input[_builtins.bool]] = None,
                 tag_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RunnerArgs.__new__(RunnerArgs)

            __props__.__dict__["access_level"] = access_level
            __props__.__dict__["description"] = description
            __props__.__dict__["locked"] = locked
            __props__.__dict__["maintenance_note"] = maintenance_note
            __props__.__dict__["maximum_timeout"] = maximum_timeout
            __props__.__dict__["paused"] = paused
            if registration_token is None and not opts.urn:
                raise TypeError("Missing required property 'registration_token'")
            __props__.__dict__["registration_token"] = None if registration_token is None else pulumi.Output.secret(registration_token)
            __props__.__dict__["run_untagged"] = run_untagged
            __props__.__dict__["tag_lists"] = tag_lists
            __props__.__dict__["authentication_token"] = None
            __props__.__dict__["status"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["authenticationToken", "registrationToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Runner, __self__).__init__(
            'gitlab:index/runner:Runner',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_level: Optional[pulumi.Input[_builtins.str]] = None,
            authentication_token: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            locked: Optional[pulumi.Input[_builtins.bool]] = None,
            maintenance_note: Optional[pulumi.Input[_builtins.str]] = None,
            maximum_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            paused: Optional[pulumi.Input[_builtins.bool]] = None,
            registration_token: Optional[pulumi.Input[_builtins.str]] = None,
            run_untagged: Optional[pulumi.Input[_builtins.bool]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tag_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Runner':
        """
        Get an existing Runner resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_level: The access_level of the runner. Valid values are: `not_protected`, `ref_protected`.
        :param pulumi.Input[_builtins.str] authentication_token: The authentication token used for building a config.toml file. This value is not present when imported.
        :param pulumi.Input[_builtins.str] description: The runner's description.
        :param pulumi.Input[_builtins.bool] locked: Whether the runner should be locked for current project.
        :param pulumi.Input[_builtins.str] maintenance_note: Free-form maintenance notes for the runner (1024 characters).
        :param pulumi.Input[_builtins.int] maximum_timeout: Maximum timeout set when this runner handles the job.
        :param pulumi.Input[_builtins.bool] paused: Whether the runner should ignore new jobs.
        :param pulumi.Input[_builtins.str] registration_token: The registration token used to register the runner.
        :param pulumi.Input[_builtins.bool] run_untagged: Whether the runner should handle untagged jobs.
        :param pulumi.Input[_builtins.str] status: The status of runners to show, one of: online and offline. active and paused are also possible values
               			              which were deprecated in GitLab 14.8 and will be removed in GitLab 16.0.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tag_lists: List of runner’s tags.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RunnerState.__new__(_RunnerState)

        __props__.__dict__["access_level"] = access_level
        __props__.__dict__["authentication_token"] = authentication_token
        __props__.__dict__["description"] = description
        __props__.__dict__["locked"] = locked
        __props__.__dict__["maintenance_note"] = maintenance_note
        __props__.__dict__["maximum_timeout"] = maximum_timeout
        __props__.__dict__["paused"] = paused
        __props__.__dict__["registration_token"] = registration_token
        __props__.__dict__["run_untagged"] = run_untagged
        __props__.__dict__["status"] = status
        __props__.__dict__["tag_lists"] = tag_lists
        return Runner(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> pulumi.Output[_builtins.str]:
        """
        The access_level of the runner. Valid values are: `not_protected`, `ref_protected`.
        """
        return pulumi.get(self, "access_level")

    @_builtins.property
    @pulumi.getter(name="authenticationToken")
    def authentication_token(self) -> pulumi.Output[_builtins.str]:
        """
        The authentication token used for building a config.toml file. This value is not present when imported.
        """
        return pulumi.get(self, "authentication_token")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The runner's description.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def locked(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the runner should be locked for current project.
        """
        return pulumi.get(self, "locked")

    @_builtins.property
    @pulumi.getter(name="maintenanceNote")
    def maintenance_note(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Free-form maintenance notes for the runner (1024 characters).
        """
        return pulumi.get(self, "maintenance_note")

    @_builtins.property
    @pulumi.getter(name="maximumTimeout")
    def maximum_timeout(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Maximum timeout set when this runner handles the job.
        """
        return pulumi.get(self, "maximum_timeout")

    @_builtins.property
    @pulumi.getter
    def paused(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the runner should ignore new jobs.
        """
        return pulumi.get(self, "paused")

    @_builtins.property
    @pulumi.getter(name="registrationToken")
    def registration_token(self) -> pulumi.Output[_builtins.str]:
        """
        The registration token used to register the runner.
        """
        return pulumi.get(self, "registration_token")

    @_builtins.property
    @pulumi.getter(name="runUntagged")
    def run_untagged(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the runner should handle untagged jobs.
        """
        return pulumi.get(self, "run_untagged")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of runners to show, one of: online and offline. active and paused are also possible values
        			              which were deprecated in GitLab 14.8 and will be removed in GitLab 16.0.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="tagLists")
    def tag_lists(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of runner’s tags.
        """
        return pulumi.get(self, "tag_lists")

